#
# Product-specific compile-time definitions.
#

include device/fsl/imx6/soc/imx6dq.mk
include device/embedian/smarc_mx6/build_id.mk
include device/fsl/imx6/BoardConfigCommon.mk
# sabresd_6dq default target for EXT4
BUILD_TARGET_FS ?= ext4
include device/fsl/imx6/imx6_target_fs.mk

ADDITIONAL_BUILD_PROPERTIES += \
                        ro.internel.storage_size=/sys/block/bootdev_size
ifneq ($(BUILD_TARGET_FS),f2fs)
TARGET_RECOVERY_FSTAB = device/embedian/smarc_mx6/fstab.freescale
# build for ext4
PRODUCT_COPY_FILES +=	\
	device/embedian/smarc_mx6/fstab.freescale:root/fstab.freescale
else
TARGET_RECOVERY_FSTAB = device/embedian/smarc_mx6/fstab-f2fs.freescale
# build for f2fs
PRODUCT_COPY_FILES +=	\
	device/embedian/smarc_mx6/fstab-f2fs.freescale:root/fstab.freescale
endif # BUILD_TARGET_FS
ADDITIONAL_BUILD_PROPERTIES += ro.frp.pst=/dev/block/by-name/presistdata

TARGET_BOOTLOADER_BOARD_NAME := smarc_ma6
PRODUCT_MODEL := smarc_fimx6

TARGET_BOOTLOADER_POSTFIX := imx
TARGET_DTB_POSTFIX := -dtb

TARGET_RELEASETOOLS_EXTENSIONS := device/fsl/imx6

# TI WILINK WIFI
USES_TI_MAC80211 := true
ifeq ($(USES_TI_MAC80211),true)
WPA_SUPPLICANT_VERSION       := VER_0_8_X

BOARD_WLAN_DEVICE            := wl12xx_mac80211
BOARD_WPA_SUPPLICANT_DRIVER  := NL80211
BOARD_WPA_SUPPLICANT_PRIVATE_LIB        := lib_driver_cmd_wl12xx

BOARD_SOFTAP_DEVICE          := wl12xx_mac80211
BOARD_HOSTAPD_DRIVER         := NL80211
BOARD_HOSTAPD_PRIVATE_LIB    := lib_driver_cmd_wl12xx
endif

USE_ATHR_GPS_HARDWARE := false
USE_QEMU_GPS_HARDWARE := false

#for accelerator sensor, need to define sensor type here
BOARD_HAS_SENSOR := false
SENSOR_MMA8451 := false

# for recovery service
TARGET_SELECT_KEY := 158

# we don't support sparse image.
TARGET_USERIMAGES_SPARSE_EXT_DISABLED := false
DM_VERITY_RUNTIME_CONFIG := true
# uncomment below lins if use NAND
#TARGET_USERIMAGES_USE_UBIFS = true


ifeq ($(TARGET_USERIMAGES_USE_UBIFS),true)
UBI_ROOT_INI := device/embedian/smarc_mx6/ubi/ubinize.ini
TARGET_MKUBIFS_ARGS := -m 4096 -e 516096 -c 4096 -x none
TARGET_UBIRAW_ARGS := -m 4096 -p 512KiB $(UBI_ROOT_INI)
endif

ifeq ($(TARGET_USERIMAGES_USE_UBIFS),true)
ifeq ($(TARGET_USERIMAGES_USE_EXT4),true)
$(error "TARGET_USERIMAGES_USE_UBIFS and TARGET_USERIMAGES_USE_EXT4 config open in same time, please only choose one target file system image")
endif
endif

BOARD_KERNEL_CMDLINE := console=ttymxc4,115200 init=/init video=mxcfb0:dev=ldb,if=RGB24,bpp=32 video=mxcfb1:off video=mxcfb2:off video=mxcfb3:off vmalloc=400M androidboot.console=ttymxc4 consoleblank=0 androidboot.hardware=freescale cma=448M androidboot.selinux=permissive androidboot.dm_verity=disabled

ifeq ($(TARGET_USERIMAGES_USE_UBIFS),true)
#UBI boot command line.
# Note: this NAND partition table must align with MFGTool's config.
BOARD_KERNEL_CMDLINE +=  mtdparts=gpmi-nand:16m(bootloader),16m(bootimg),128m(recovery),-(root) gpmi_debug_init ubi.mtd=3
endif

# WL12xx/WL18xx BT
BOARD_HAVE_BLUETOOTH_TI := true
BOARD_BLUETOOTH_BDROID_BUILDCFG_INCLUDE_DIR := device/embedian/smarc_mx6/bluetooth

USE_ION_ALLOCATOR := false
USE_GPU_ALLOCATOR := true

# define frame buffer count
NUM_FRAMEBUFFER_SURFACE_BUFFERS := 3

PHONE_MODULE_INCLUDE := true
# camera hal v3
IMX_CAMERA_HAL_V3 := true


#define consumer IR HAL support
IMX6_CONSUMER_IR_HAL := false

TARGET_KERNEL_DEFCONF := smarcfimx6_android_defconfig

TARGET_BOOTLOADER_CONFIG := smarcfimx6_quad_1g_ser3_android_defconfig smarcfimx6_quad_2g_ser3_android_defconfig smarcfimx6_dl_1g_ser3_android_defconfig smarcfimx6_solo_ser3_android_defconfig smarcfimx6_solo_1g_ser3_android_defconfig
TARGET_BOARD_DTS_CONFIG := smarcfimx6dq:imx6q-smarcfimx6.dtb smarcfimx6dl:imx6dl-smarcfimx6.dtb smarcfimx6dq-wvga:imx6q-smarcfimx6-wvga.dtb smarcfimx6dl-wvga:imx6dl-smarcfimx6-wvga.dtb smarcfimx6dq-xga:imx6q-smarcfimx6-xga.dtb smarcfimx6dl-xga:imx6dl-smarcfimx6-xga.dtb smarcfimx6dq-wxga:imx6q-smarcfimx6-wxga.dtb smarcfimx6dl-wxga:imx6dl-smarcfimx6-wxga.dtb smarcfimx6dq-1080p:imx6q-smarcfimx6-1080p.dtb smarcfimx6dl-1080p:imx6dl-smarcfimx6-1080p.dtb

BOARD_SEPOLICY_DIRS := \
       device/fsl/imx6/sepolicy \
       device/embedian/imx6/sepolicy 
# Support gpt
BOARD_BPT_INPUT_FILES += device/embedian/common/partition/device-partitions.bpt

BOARD_SECCOMP_POLICY += device/embedian/smarc_mx6/seccomp

TARGET_BOARD_KERNEL_HEADERS := device/fsl/common/kernel-headers
